@@ -95,7 +95,7 @@ tidy_negative_binomial <- function(.n = 50, .size = 1, .prob = .1, .num_sims = 1
       purrr::set_names("dx", "dy") %>%
       dplyr::as_tibble())) %>%
     dplyr::mutate(p = list(stats::pnbinom(ps, size = size, prob = prob))) %>%
-    dplyr::mutate(q = list(stats::qnbinom(qs, size = size, prob = prob))) %>%
+    dplyr::mutate(q = list(stats::qnbinom(tidy_scale_zero_one_vec(unlist(y)), size = size, prob = prob))) %>%
     tidyr::unnest(cols = c(x, y, d, p, q)) %>%
     dplyr::ungroup()
 
